@@ -16,7 +16,10 @@ test_that("discrete fill works", {
     scale_fill_taylor_d(album = "Fearless (Taylor's Version)")
 
   speak_now <- fill_base +
-    scale_fill_taylor_d(album = "speak_now")
+    scale_fill_taylor_d(album = "Speak Now")
+
+  speak_now_tv <- fill_base +
+    scale_fill_taylor_d(album = "Speak Now (Taylor's Version)")
 
   red <- fill_base +
     scale_fill_taylor_d(album = "Red")
@@ -27,6 +30,9 @@ test_that("discrete fill works", {
   `1989` <- fill_base +
     scale_fill_taylor_d(album = "1989")
 
+  `1989_tv` <- fill_base +
+    scale_fill_taylor_d(album = "1989 (Taylor's Version)")
+
   reputation <- fill_base +
     scale_fill_taylor_d(album = "reputation")
 
@@ -46,9 +52,11 @@ test_that("discrete fill works", {
   vdiffr::expect_doppelganger("fearless-fill-d", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-d", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-fill-d", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-fill-d", speak_now_tv)
   vdiffr::expect_doppelganger("red-fill-d", red)
   vdiffr::expect_doppelganger("red-tv-fill-d", red_tv)
   vdiffr::expect_doppelganger("1989-fill-d", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-fill-d", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-fill-d", reputation)
   vdiffr::expect_doppelganger("lover-fill-d", lover)
   vdiffr::expect_doppelganger("folklore-fill-d", folklore)
@@ -71,7 +79,10 @@ test_that("discrete color works", {
     scale_color_taylor_d(album = "Fearless (Taylor's Version)")
 
   speak_now <- color_base +
-    scale_color_taylor_d(album = "speak_now")
+    scale_color_taylor_d(album = "Speak Now")
+
+  speak_now_tv <- color_base +
+    scale_color_taylor_d(album = "Speak Now (Taylor's Version)")
 
   red <- color_base +
     scale_color_taylor_d(album = "Red")
@@ -82,6 +93,9 @@ test_that("discrete color works", {
   `1989` <- color_base +
     scale_color_taylor_d(album = "1989")
 
+  `1989_tv` <- color_base +
+    scale_color_taylor_d(album = "1989 (Taylor's Version)")
+
   reputation <- color_base +
     scale_color_taylor_d(album = "reputation")
 
@@ -101,9 +115,11 @@ test_that("discrete color works", {
   vdiffr::expect_doppelganger("fearless-color-d", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-d", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-color-d", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-color-d", speak_now_tv)
   vdiffr::expect_doppelganger("red-color-d", red)
   vdiffr::expect_doppelganger("red-tv-color-d", red_tv)
   vdiffr::expect_doppelganger("1989-color-d", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-color-d", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-color-d", reputation)
   vdiffr::expect_doppelganger("lover-color-d", lover)
   vdiffr::expect_doppelganger("folklore-color-d", folklore)
@@ -160,7 +176,10 @@ test_that("continuous fill works", {
     scale_fill_taylor_c(album = "Fearless (Taylor's Version)")
 
   speak_now <- fill_base +
-    scale_fill_taylor_c(album = "speak_now")
+    scale_fill_taylor_c(album = "Speak Now")
+
+  speak_now_tv <- fill_base +
+    scale_fill_taylor_c(album = "Speak Now (Taylor's Version)")
 
   red <- fill_base +
     scale_fill_taylor_c(album = "Red")
@@ -171,6 +190,9 @@ test_that("continuous fill works", {
   `1989` <- fill_base +
     scale_fill_taylor_c(album = "1989")
 
+  `1989_tv` <- fill_base +
+    scale_fill_taylor_c(album = "1989 (Taylor's Version)")
+
   reputation <- fill_base +
     scale_fill_taylor_c(album = "reputation")
 
@@ -190,9 +212,11 @@ test_that("continuous fill works", {
   vdiffr::expect_doppelganger("fearless-fill-c", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-c", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-fill-c", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-fill-c", speak_now_tv)
   vdiffr::expect_doppelganger("red-fill-c", red)
   vdiffr::expect_doppelganger("red-tv-fill-c", red_tv)
   vdiffr::expect_doppelganger("1989-fill-c", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-fill-c", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-fill-c", reputation)
   vdiffr::expect_doppelganger("lover-fill-c", lover)
   vdiffr::expect_doppelganger("folklore-fill-c", folklore)
@@ -342,7 +366,10 @@ test_that("continuous color works", {
     scale_color_taylor_c(album = "Fearless (Taylor's Version)")
 
   speak_now <- color_base +
-    scale_color_taylor_c(album = "speak_now")
+    scale_color_taylor_c(album = "Speak Now")
+
+  speak_now_tv <- color_base +
+    scale_color_taylor_c(album = "Speak Now (Taylor's Version)")
 
   red <- color_base +
     scale_color_taylor_c(album = "Red")
@@ -353,6 +380,9 @@ test_that("continuous color works", {
   `1989` <- color_base +
     scale_color_taylor_c(album = "1989")
 
+  `1989_tv` <- color_base +
+    scale_color_taylor_c(album = "1989 (Taylor's Version)")
+
   reputation <- color_base +
     scale_color_taylor_c(album = "reputation")
 
@@ -372,9 +402,11 @@ test_that("continuous color works", {
   vdiffr::expect_doppelganger("fearless-color-c", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-c", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-color-c", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-color-c", speak_now_tv)
   vdiffr::expect_doppelganger("red-color-c", red)
   vdiffr::expect_doppelganger("red-tv-color-c", red_tv)
   vdiffr::expect_doppelganger("1989-color-c", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-color-c", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-color-c", reputation)
   vdiffr::expect_doppelganger("lover-color-c", lover)
   vdiffr::expect_doppelganger("folklore-color-c", folklore)
@@ -399,6 +431,9 @@ test_that("binned fill works", {
   speak_now <- fill_base +
     scale_fill_taylor_b(album = "Speak Now")
 
+  speak_now_tv <- fill_base +
+    scale_fill_taylor_b(album = "Speak Now (Taylor's Version)")
+
   red <- fill_base +
     scale_fill_taylor_b(album = "Red")
 
@@ -408,6 +443,9 @@ test_that("binned fill works", {
   `1989` <- fill_base +
     scale_fill_taylor_b(album = "1989")
 
+  `1989_tv` <- fill_base +
+    scale_fill_taylor_b(album = "1989 (Taylor's Version)")
+
   reputation <- fill_base +
     scale_fill_taylor_b(album = "reputation")
 
@@ -427,9 +465,11 @@ test_that("binned fill works", {
   vdiffr::expect_doppelganger("fearless-fill-b", fearless)
   vdiffr::expect_doppelganger("fearless-tv-fill-b", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-fill-b", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-fill-b", speak_now_tv)
   vdiffr::expect_doppelganger("red-fill-b", red)
   vdiffr::expect_doppelganger("red-tv-fill-b", red_tv)
   vdiffr::expect_doppelganger("1989-fill-b", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-fill-b", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-fill-b", reputation)
   vdiffr::expect_doppelganger("lover-fill-b", lover)
   vdiffr::expect_doppelganger("folklore-fill-b", folklore)
@@ -454,6 +494,9 @@ test_that("binned color work", {
   speak_now <- color_base +
     scale_color_taylor_b(album = "Speak Now")
 
+  speak_now_tv <- color_base +
+    scale_color_taylor_b(album = "Speak Now (Taylor's Version)")
+
   red <- color_base +
     scale_color_taylor_b(album = "Red")
 
@@ -463,6 +506,9 @@ test_that("binned color work", {
   `1989` <- color_base +
     scale_color_taylor_b(album = "1989")
 
+  `1989_tv` <- color_base +
+    scale_color_taylor_b(album = "1989 (Taylor's Version)")
+
   reputation <- color_base +
     scale_color_taylor_b(album = "reputation")
 
@@ -482,9 +528,11 @@ test_that("binned color work", {
   vdiffr::expect_doppelganger("fearless-color-b", fearless)
   vdiffr::expect_doppelganger("fearless-tv-color-b", fearless_tv)
   vdiffr::expect_doppelganger("speak-now-color-b", speak_now)
+  vdiffr::expect_doppelganger("speak-now-tv-color-b", speak_now_tv)
   vdiffr::expect_doppelganger("red-color-b", red)
   vdiffr::expect_doppelganger("red-tv-color-b", red_tv)
   vdiffr::expect_doppelganger("1989-color-b", `1989`)
+  vdiffr::expect_doppelganger("1989-tv-color-b", `1989_tv`)
   vdiffr::expect_doppelganger("reputation-color-b", reputation)
   vdiffr::expect_doppelganger("lover-color-b", lover)
   vdiffr::expect_doppelganger("folklore-color-b", folklore)
@@ -494,6 +542,7 @@ test_that("binned color work", {
 
 test_that("album scale works", {
   studio <- subset(taylor_albums, !ep)
+  studio$metacritic_score[which(is.na(studio$metacritic_score))] <- 92L
 
   # no leveling
   no_level <- ggplot(studio, aes(x = metacritic_score, y = album_name)) +
